@@ -1,7 +1,14 @@
 # flake8: noqa
+__all__ = [
+    "Client",
+    "CollectionClient",
+    "ConformanceClasses",
+    "ItemSearch",
+    "__version__",
+]
 
-from pystac_client.version import __version__
-from pystac_client.item_search import ItemSearch
 from pystac_client.client import Client
 from pystac_client.collection_client import CollectionClient
 from pystac_client.conformance import ConformanceClasses
+from pystac_client.item_search import ItemSearch
+from pystac_client.version import __version__
